@@ -19,11 +19,10 @@ from pyro.contrib.conjugate.infer import (
 )
 from pyro.infer import SVI, TraceEnum_ELBO
 from pyro.infer.autoguide import AutoDelta
-# from pyro.infer.mcmc.api import MCMC
 from pyro.util import ignore_jit_warnings
 
-from sbi.mcmc.mcmc import MCMC
-from sbi.mcmc.slice import Slice
+from sbi.samplers.mcmc.mcmc import MCMC
+from sbi.samplers.mcmc.slice import Slice
 
 from .common import assert_equal
 
@@ -219,7 +218,7 @@ def test_beta_bernoulli():
         return p_latent
 
     true_probs = torch.tensor([0.9, 0.1])
-    data = dist.Bernoulli(true_probs).sample(sample_shape=(torch.Size((1000,))))
+    data = dist.Bernoulli(true_probs).sample(sample_shape=(torch.Size((1200,))))
     slice_kernel = Slice(model)
     mcmc = MCMC(slice_kernel, num_samples=400, warmup_steps=200)
     mcmc.run(data)
